#
# spec file for package xfce4-taskmanager
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xfce4-taskmanager
Version:        1.5.8
Release:        1.2
Summary:        Simple Taskmanager for the Xfce Desktop Environment
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://docs.xfce.org/apps/xfce4-taskmanager
Source:         https://archive.xfce.org/src/apps/%{name}/1.5/%{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE xfce4-taskmanager-relax-x11-version.patch lower required X11 version to allow building for Leap which only has 1.6.5, which is enough, though
Patch0:         xfce4-taskmanager-relax-x11-version.patch
BuildRequires:  gettext >= 0.19.8
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cairo) >= 1.5.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libwnck-3.0) >= 3.2
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.14
BuildRequires:  pkgconfig(libxfconf-0) >= 4.14
BuildRequires:  pkgconfig(x11) >= 1.6.5
BuildRequires:  pkgconfig(xmu) >= 1.1.2
# uses exo-open
Requires:       exo-tools
Recommends:     %{name}-lang = %{version}

%description
xfce4-taskmanager is a simple taskmanager for the Xfce desktop environment. It
can display window and icon names in a tree view, columns can be reordered, and
CPU and memory usage are displayed as a graph.

%lang_package

%prep
%autosetup -p1

%build
%configure \
	--enable-gtk3
%make_build

%install
%make_install

%suse_update_desktop_file -r %{name} GTK System Monitor

%find_lang %{name} %{?no_lang_C}

%files
%doc AUTHORS NEWS README.md THANKS
%license COPYING
%{_bindir}/xfce4-taskmanager
%{_datadir}/applications/xfce4-taskmanager.desktop
%{_datadir}/icons/hicolor/*/actions/xc_crosshair*
%{_datadir}/icons/hicolor/*/apps/org.xfce.taskmanager.*

%files lang -f %{name}.lang

%changelog
* Mon Dec 30 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.5.8
  * Add Darwin support
  * I18n: Update po/LINGUAS list
  * Added missing Keywords entry to .desktop file
  * Fix leak when copying command line string
  * Fix core.UndefinedBinaryOperatorResult warning from scan-build
  * clang-format: Use IncludeBlocks::Regroup
  * Apply .clang-format file
  * Clean up and sort includes
  * clang-format: Add file
  * Aggregate children memory and cpu
  * process-tree-view: Reset /columns/positions at startup if invalid
  * Fix xfconf memory management
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * build: Switch from intltool to gettext
  * Fix search filter memory leaks
  * Translation Updates
- Refresh xfce4-taskmanager-relax-x11-version.patch
* Fri Mar  1 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.5.7
  * Update copyright year
  * build: Fix -Wcast-align warning from clang
  * Fix UBSan errors
  * settings-dialog: Fix XtmRefreshRate memory leak
  * Dark mode for process-statusbar
  * Dark mode for process-monitor
  * Allow multiple instances via command line option.
  * Fix blurry app icons when UI scale > 1
  * Use symbolic window picker icon in toolbar
  * Fix broken "show-legend" setting sync
  * Translation Updates
- Add xfce4-taskmanager-relax-x11-version.patch
* Mon Oct  2 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.5.6
  * Update copyright year
  * Rounded legend icons
  * Reopen process window maximized when closed maximized
  * Properly finalize global objects in main
  * Add missing include
  * Fix more memory leaks
  * Fix memory leak
  * Fix CSS related deprecation warnings
  * Ignore GtkStatusIcon related deprecations
  * Make libx11 optional, guard x11 code paths
  * Change type so that memory values are correct (Fixes #65)
  * settings-dialog: Fix untranslated label
  * Add icons at missing sizes, clean up SVG metadata
  * Add minimal support for Wayland
  * Fix graph drop off on the right side
  * Change graph peak variable to double
  * Remove timeout before exiting main loop
  * build: Add GLib requirement
  * Do not treat missing swap as error on OpenBSD and NetBSD
  * Fix process filter crash caused by the use of an uninitialized
    variable
  * Translation Updates
* Thu Dec 22 2022 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.5.5
  * Bump requirements for Xfce 4.18
  * Stick process view at the top in the absence of user action
  * Get rid of GtkHeaderBar
  * Translation Updates
* Tue May 31 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 1.5.4
  * Update configure.ac.in syntax
  * Fix taskmanager translations (gxo#apps/xfce4-taskmanager#53)
  * Translation Updates
- Updates from 1.5.3
  * Fix rendering bug (gxo#apps/xfce4-taskmanager#44)
  * Fix rendering bug for swap graph (gxo#apps/xfce4-taskmanager#44)
  * Fix bindings related to the "show-legend" setting
  * Allow to copy full process command line (gxo#apps/xfce4-taskmanager#33)
  * Rename Private to Resident Bytes (gxo#apps/xfce4-taskmanager#7)
  * Avoid grabbing the filter entry if it is not realized
  * Fix intltool lock file problem during make distcheck
  * `uid_name` has been removed from `task` struct
  * Fix invalid casts for "About" and "Help" (gxo#apps/xfce4-taskmanager#43)
  * Show localized website label
  * Update COPYING (gxo#apps/xfce4-taskmanager#49)
  * Updated copyright year, authors, and project links
- Updates from version 1.5.2
  * Fix restoring the window size (gxo#apps/xfce4-taskmanager#39)
  * Improve wording of systray option (gxo#apps/xfce4-taskmanager#19)
- Updates from version 1.5.1
  * Fix erroneous binding of settings (gxo#apps/xfce4-taskmanager#37)
  * Store column positions again
  * Store sort-column-id and sort-type (gxo#apps/xfce4-taskmanager#36)
  * Also include swap in the memory graph
  * Reduce drawing code
  * Reduce borders of graphs
  * Replace GtkImageMenuItem with GtkMenuItem
- Updates from version 1.5.0
  * Port to xfconf
  * Move to Client-side decorations
  * Migrate all settings to the settings dialog
  * settings: Switch to XfceTitledDialog
  * Use infobar for root warning box
  * Drop exec button from toolbar
  * include stdlib.h because exit() is used
  * remove GLIB_CHECK_VERSION checks
  * statusbar: Use better color that works well with both light and dark
    themes (gxo#apps/xfce4-taskmanager!17)
  * Fix handling "show-legend" setting
  * Handle Esc key correctly with hidden filter
  * Drop unused var and sort copyright
  * Show/hide filterbar with Ctrl+f and clear with Esc
  * Properly close settings dialog
  * Remove GSourceFunc casts
  * Fix compilation warnings
  * Replace AC_PROG_LIBTOOL with IT_PROG_INTLTOOL
  * Simplify "query-tooltip" signal handler
  * Ellipsize memory and swap labels (gxo#apps/xfce4-taskmanager#32)
  * Set window icon in glade file
  * Replace filter entry with GtkSearchBar
  * Fix doc links and bump dates
  * Simplify settings dialog code
  * Drop leftover function for toolbar style
  * Move about dialog to settings
  * Drop toolbar style setting
  * Fix tooltip markdown issue
  * Create notification area icon only if needed (gxo#apps/xfce4-taskmanager#25)
* Tue Feb  9 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.4.2
  * Ellipsize memory and swap labels (gxo#apps/xfce4-taskmanager#32)
* Mon Feb  8 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.4.1
  * Replace AC_PROG_LIBTOOL with IT_PROG_INTLTOOL
  * Simplify "query-tooltip" signal handler
  * statusbar: Use better color that works well with both light
    and dark themes (gxo#apps/xfce4-taskmanager!17)
  * Fix tooltip markdown issue
  * Create notification area icon only if needed
    (gxo#apps/xfce4-taskmanager#25)
* Tue Dec 29 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.4.0
  * Drop Gtk2 support
  * Add support for MemAvailable (gxo#apps/xfce4-taskmanager!10)
  * statusbar: Use color with better contrast for dark themes
  * Fix: some times processes are not removed from the list
  * Add tooltip to show full command
  * Add application icon (gxo#apps/xfce4-taskmanager#23)
  * Replace appfinder icon with edit-find
    (gxo#apps/xfce4-taskmanager#23)
  * Replace old icon name with utilities-terminal
    gxo#apps/xfce4-taskmanager#23
  * Replace old icon name with system-run
    gxo#apps/xfce4-taskmanager#23
  * Always show memory usage in bytes and percent
    (gxo#apps/xfce4-taskmanager#24)
  * Improve comment in desktop file
    (gxo#apps/xfce4-taskmanager#20)
  * Add basic GitLab pipeline
  * Add README.md
  * Update libwnck and xmu deps in README
  * Remove GKSU leftovers
  * Remove unused url_hook_about_dialog function
  * Replace deprecated gtk_menu_popup
  * Fix GTimeVal deprecation warning
  * Fix indentation
  * Update .gitignore
  * AC_CONFIG_MACRO_DIR → AC_CONFIG_MACRO_DIRS
  * Bump minimal xdt version
  * bxo#16717: Move from exo-csource to xdt-csource
  * Translation Updates
* Fri Apr 10 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.2.3
  * Improve settings saving (bxo#15213)
  * Fix closing taskman with Esc (bxo#16656)
  * Move legend from tooltip to hide-able statusbar (bxo#14131)
  * Update copyright
  * Translation Updates
* Wed Jan  2 2019 Maurizio Galli <maurizio.galli@gmail.com>
- update to version 1.2.2
  - Default to build with Gtk3, Gtk2 still available but will be removed
    in the next release
  - Appease valgrind by properly calculating size when using memmove
  - Remove g_object_unref() calls at the end of main, were causing
    double-frees with Gtk3 on OpenBSD
  - Better utf-8 normalization (bxo#14172)
  - Improve app search on close (bxo#14466)
  - Many translation updates
* Sat Jun  9 2018 seife+obs@b1-systems.com
- update to version 1.2.1
  - New Feature: add --start-hidden commandline option (bxo#14343)
  - Fix incorrect UID reporting (bxo#12970)
  - Fix memory usage display (bxo#13371)
  - Fix various types/casts/initializations/leaks (bxo#14401,
    bxo#14402, bxo#14403)
  - Possible fix for a crash when lots of processes were
    spawned/disappeared
  - Translation updates
- packaging:
  - build against GTK3
  - use %%license
* Wed Apr 19 2017 seife+obs@b1-systems.com
- update to version 1.2.0
  - New Feature: identify windows by clicking on them
  - Give the filter/search entry focus by default (bxo#11868)
  - Add delete and shift/delete keyboard shortcuts to the treeview
  - Improve kill and terminate dialog wording
  - Add Ctrl+q keyboard shortcut to close the taskmanager
  - Translation updates
* Wed Dec 24 2014 gber@opensuse.org
- update to version 1.1.0
  - stop using lots of deprecated Gtk2 API
  - add a process treeview mode
  - general UI/graph overhaul
  - various crash & correctness fixes on the bsd backend
  - add a searchbox to filter on process names (bxo#9856)
  - make Escape key close the main window (bxo#11343)
  - fix window settings not properly saved (bxo#10670)
  - fix build issue on FreeBSD 9.0 (bxo#8081)
  - fix the refresh rate menu
  - default the focus on the process list instead of the exec button
    (bxo#10643)
  - add an option to show memory/swap usage as bytes instead of %%
    (bxo#6503)
  - add unique app behaviour (bxo#8808)
  - default to close the window instead of hiding in systray
    (bxo#10941)
  - fix type causing high cpu usage on ARM (bxo#10417)
  - tons of translation updates
* Wed Jan  8 2014 gber@opensuse.org
- update to version 1.0.1
  - add "Run Task Manager as root" item in "Execute" menu
  - add a menu position function
  - fix shell substitution for Korn Shell (ksh)
  - set monitor's background box use the prelight state
  - remove quit tool button
  - OpenBSD removed KERN_PROC2/KINFO_PROC2 some months ago.
  - translation updates
* Sun Apr 29 2012 gber@opensuse.org
- add dependency on exo-tools since exo-open is used
* Fri Mar 30 2012 gber@opensuse.org
- specfile cleanup
- split off -lang subpackage
* Fri Feb 18 2011 gber@opensuse.org
- call %%desktop_database_post/un
* Mon Dec 27 2010 gber@opensuse.org
- use libwnck
- drop obsolete build dependencies
- show compiler output
- remove unsupported locales
- improved summaries/descriptions
* Tue Jun 15 2010 prusnak@opensuse.org
- updated to 1.0.0
  - Replaced progress bars against monitors
  - Display window icons/names with libwnck (optional)
  - Display the tree view context menu on Menu key press
  - On tree view column click sort first by descending order
  - Context menu on the status icon to quit the application
  - Hide window on window close when the status icon is visible
  - Several fixes
* Wed Oct  8 2008 bwalle@suse.de
- Add suse_update_desktop_file to fix build on Factory
* Wed Jun 18 2008 prusnak@suse.cz
- updated to 0.4.0
  * Priority setting
  * 64bit archs fix
  * Update strings
- dropped obsoleted patch: signal.diff
* Tue Dec  4 2007 prusnak@suse.cz
- use %%find_lang macro
- do not package INSTALL file
- replace startup-notification with startup-notification-devel
* Sat Jun 23 2007 bwalle@suse.de
- replaced group 'System/GUI/Other' by 'System/GUI/Xfce'
* Tue May 22 2007 prusnak@suse.cz
- sync with BuildService
* Thu Mar  8 2007 prusnak@suse.cz
- added norootforbuild
* Tue Feb 13 2007 prusnak@suse.cz
- fixed comparison of a char* pointer with a string literal (signal.diff)
* Mon Jan 29 2007 pnemec@suse.cz
- package merged from BuildService at version 0.4.0
* Tue Aug 22 2006 bernhard.walle@gmx.de
- initial package
